﻿using ProjectSchedule.Entities.Enums;
using ProjectSchedule.Entities;
using ProjectSchedule.Repositories;

namespace ProjectSchedule.Forms;

public partial class FormAudience : Form
{
    private readonly IAudienceRepository _audienceRepository;

    private int? _audienceId;

    public int Id
    {
        set
        {
            try
            {
                var audience = _audienceRepository.ReadAudienceById(value);
                if (audience == null)
                {
                    throw new InvalidDataException(nameof(audience));
                }

                foreach (TypeAudience elem in Enum.GetValues(typeof(TypeAudience)))
                {
                    if ((elem & audience.TypeAudience) != 0)
                    {
                        checkedListBoxTypeAudience.SetItemChecked(checkedListBoxTypeAudience.Items.IndexOf(elem), true);
                    }
                }

                textBoxNumberAudience.Text = audience.NumberAudience;
                numericUpDownQuantitySeats.Value = audience.QuantitySeats;
                _audienceId = value;
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Ошибка при получении данных", MessageBoxButtons.OK, MessageBoxIcon.Error);
                return;
            }
        }
    }

    public FormAudience(IAudienceRepository audienceRepository)
    {
        InitializeComponent();
        _audienceRepository = audienceRepository ??
            throw new ArgumentNullException(nameof(audienceRepository));

        foreach (var elem in Enum.GetValues(typeof(TypeAudience)))
        {
            checkedListBoxTypeAudience.Items.Add(elem);
        }
    }

    private void ButtonSave_Click(object sender, EventArgs e)
    {
        try
        {
            if (string.IsNullOrWhiteSpace(textBoxNumberAudience.Text) || checkedListBoxTypeAudience.CheckedItems.Count == 0)
            {
                throw new Exception("Имеются незаполненные поля");
            }

            if (_audienceId.HasValue)
            {
                _audienceRepository.UpdateAudience(CreateAudience(_audienceId.Value));
            }
            else
            {
                _audienceRepository.CreateAudience(CreateAudience(0));
            }

            Close();
        }
        catch (Exception ex)
        {
            MessageBox.Show(ex.Message, "Ошибка при сохранении", MessageBoxButtons.OK, MessageBoxIcon.Error);
        }
    }

    private void ButtonCancel_Click(object sender, EventArgs e) => Close();

    private Audience CreateAudience(int id)
    {
        TypeAudience typeAudience = TypeAudience.None;
        foreach (var elem in checkedListBoxTypeAudience.CheckedItems)
        {
            typeAudience |= (TypeAudience)elem;
        }

        return Audience.CreateEntity(id, textBoxNumberAudience.Text, typeAudience, Convert.ToInt32(numericUpDownQuantitySeats.Value));
    }
}