﻿using ProjectSchedule.Entities;
using ProjectSchedule.Entities.Enums;
using ProjectSchedule.Repositories;

namespace ProjectSchedule.Forms
{
    public partial class FormCompilingSchedule : Form
    {
        private readonly ICompilingScheduleRepository _сompilingScheduleRepository;

        public FormCompilingSchedule(ICompilingScheduleRepository сompilingScheduleRepository, IDisciplineRepository disciplineRepository,
            IEducatorRepository educatorRepository, IGroupStudentsRepository groupStudentsRepository, IAudienceRepository audienceRepository)
        {
            InitializeComponent();

            _сompilingScheduleRepository = сompilingScheduleRepository ??
                throw new ArgumentNullException(nameof(сompilingScheduleRepository));

            comboBoxEducator.DataSource = educatorRepository.ReadEducators();
            comboBoxEducator.DisplayMember = "Surname";
            comboBoxEducator.ValueMember = "Id";

            comboBoxDiscipline.DataSource = disciplineRepository.ReadDisciplines();
            comboBoxDiscipline.DisplayMember = "NameDiscipline";
            comboBoxDiscipline.ValueMember = "Id";

            comboBoxGroupStudents.DataSource = groupStudentsRepository.ReadGroupsStudents();
            comboBoxGroupStudents.DisplayMember = "AbbreviationGroup";
            comboBoxGroupStudents.ValueMember = "Id";

            comboBoxAudience.DataSource = audienceRepository.ReadAudiences();
            comboBoxAudience.DisplayMember = "NumberAudience";
            comboBoxAudience.ValueMember = "Id";

            comboBoxTypeWeek.DataSource = Enum.GetValues(typeof(TypeWeek));

            comboBoxTypeActivity.DataSource = Enum.GetValues(typeof(TypeActivity));
        }

        private void ButtonSave_Click(object sender, EventArgs e)
        {
            try
            {
                if (comboBoxEducator.SelectedIndex < 0 || comboBoxDiscipline.SelectedIndex < 0 || comboBoxGroupStudents.SelectedIndex < 0 ||
                    comboBoxAudience.SelectedIndex < 0 || comboBoxTypeWeek.SelectedIndex < 1 || comboBoxTypeActivity.SelectedIndex < 1)
                {
                    throw new Exception("Имеются незаполненные поля");
                }

                _сompilingScheduleRepository.CreateCompilingSchedule(CompilingSchedule.CreateOperation(0, (int)comboBoxEducator.SelectedValue!,
                    (int)comboBoxDiscipline.SelectedValue!, (int)comboBoxGroupStudents.SelectedValue!, (int)comboBoxAudience.SelectedValue!,
                    dateTimePickerDateDay.Value, (TypeWeek)comboBoxTypeWeek.SelectedItem!, Convert.ToInt32(numericUpDownNumberDay.Value),
                    Convert.ToInt32(numericUpDownNumberPair.Value), (TypeActivity)comboBoxTypeActivity.SelectedItem!));

                Close();
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Ошибка сохранения", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        private void ButtonCancel_Click(object sender, EventArgs e) => Close();
    }
}