﻿using ProjectSchedule.Entities;
using ProjectSchedule.Repositories;

namespace ProjectSchedule.Forms
{
    public partial class FormCurriculumSupplement : Form
    {
        private readonly ICurriculumSupplementRepository _curriculumSupplementRepository;

        public FormCurriculumSupplement(ICurriculumSupplementRepository curriculumSupplementRepository,
            IDisciplineRepository disciplineRepository, IGroupStudentsRepository groupStudentsRepository)
        {
            InitializeComponent();
            _curriculumSupplementRepository = curriculumSupplementRepository ??
                throw new ArgumentNullException(nameof(curriculumSupplementRepository));

            comboBoxGroupStudents.DataSource = groupStudentsRepository.ReadGroupsStudents();
            comboBoxGroupStudents.DisplayMember = "AbbreviationGroup";
            comboBoxGroupStudents.ValueMember = "Id";

            ColumnDiscipline.DataSource = disciplineRepository.ReadDisciplines();
            ColumnDiscipline.DisplayMember = "NameDiscipline";
            ColumnDiscipline.ValueMember = "Id";
        }

        private void ButtonSave_Click(object sender, EventArgs e)
        {
            try
            {
                if (dataGridViewDisciplines.RowCount < 1 || comboBoxGroupStudents.SelectedIndex < 0 || 
                    string.IsNullOrWhiteSpace(textBoxNameCurriculum.Text) || string.IsNullOrWhiteSpace(textBoxSemester.Text))
                {
                    throw new Exception("Имеются незаполненные поля");
                }

                _curriculumSupplementRepository.CreateCurriculumSupplement(CurriculumSupplement.CreateOperation(0,
                    (int)comboBoxGroupStudents.SelectedValue!, textBoxNameCurriculum.Text, textBoxSemester.Text,
                    dateTimePickerDateAdoptionPlan.Value, CreateListDisciplineCurriculumSupplementsFromDataGrid()));

                Close();
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Ошибка при сохранении", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        private void ButtonCancel_Click(object sender, EventArgs e) => Close();

        private List<DisciplineCurriculumSupplement> CreateListDisciplineCurriculumSupplementsFromDataGrid()
        {
            var list = new List<DisciplineCurriculumSupplement>();
            foreach (DataGridViewRow row in dataGridViewDisciplines.Rows)
            {
                if (row.Cells["ColumnDiscipline"].Value == null || row.Cells["ColumnQuantityLectures"].Value == null ||
                    row.Cells["ColumnQuantityPractices"].Value == null)
                {
                    continue;
                }

                list.Add(DisciplineCurriculumSupplement.CreateElement(0, Convert.ToInt32(row.Cells["ColumnDiscipline"].Value),
                    Convert.ToInt32(row.Cells["ColumnQuantityLectures"].Value),
                    Convert.ToInt32(row.Cells["ColumnQuantityPractices"].Value)));
            }

            return list;
        }
    } 
}