﻿using ProjectSchedule.Repositories;
using Unity;

namespace ProjectSchedule.Forms
{
    public partial class FormCurriculumSupplements : Form
    {
        private readonly IUnityContainer _container;

        private readonly ICurriculumSupplementRepository _curriculumSupplementRepository;

        public FormCurriculumSupplements(IUnityContainer container, ICurriculumSupplementRepository curriculumSupplementRepository)
        {
            InitializeComponent();

            _container = container ??
                throw new ArgumentNullException(nameof(container));
            _curriculumSupplementRepository = curriculumSupplementRepository ??
                throw new ArgumentNullException(nameof(curriculumSupplementRepository));
        }

        private void FormCurriculumSupplements_Load(object sender, EventArgs e)
        {
            try
            {
                LoadList();
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Ошибка при загрузке", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        private void ButtonAdd_Click(object sender, EventArgs e)
        {
            try
            {
                _container.Resolve<FormCurriculumSupplement>().ShowDialog();
                LoadList();
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Ошибка при добавлении", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        private void ButtonDel_Click(object sender, EventArgs e)
        {
            if (!TryGetIdentifierFromSelectedRow(out var findId))
            {
                return;
            }

            if (MessageBox.Show("Удалить запись?", "Удаление", MessageBoxButtons.YesNo) != DialogResult.Yes)
            {
                return;
            }

            try
            {
                _curriculumSupplementRepository.DeleteCurriculumSupplement(findId);
                LoadList();
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Ошибка при удалении", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        private void LoadList() =>
            dataGridViewData.DataSource = _curriculumSupplementRepository.ReadCurriculumSupplements();

        private bool TryGetIdentifierFromSelectedRow(out int id)
        {
            id = 0;
            if (dataGridViewData.SelectedRows.Count < 1)
            {
                MessageBox.Show("Нет выбранной записи", "Ошибка", MessageBoxButtons.OK, MessageBoxIcon.Error);
                return false;
            }

            id = Convert.ToInt32(dataGridViewData.SelectedRows[0].Cells["Id"].Value);
            return true;
        }
    }
}