﻿using ProjectSchedule.Entities;
using ProjectSchedule.Repositories;

namespace ProjectSchedule.Forms;

public partial class FormDiscipline : Form
{
    private readonly IDisciplineRepository _disciplineRepository;

    private int? _disciplineId;

    public int Id
    {
        set
        {
            try
            {
                var discipline = _disciplineRepository.ReadDisciplineById(value);
                if (discipline == null)
                {
                    throw new InvalidDataException(nameof(discipline));
                }

                textBoxNameDiscipline.Text = discipline.NameDiscipline;
                _disciplineId = value;
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Ошибка при получении данных", MessageBoxButtons.OK, MessageBoxIcon.Error);
                return;
            }
        }
    }

    public FormDiscipline(IDisciplineRepository disciplineRepository)
    {
        InitializeComponent();
        _disciplineRepository = disciplineRepository ??
            throw new ArgumentNullException(nameof(disciplineRepository));
    }

    private void ButtonSave_Click(object sender, EventArgs e)
    {
        try
        {
            if (string.IsNullOrWhiteSpace(textBoxNameDiscipline.Text))
            {
                throw new Exception("Поле 'Название дисциплины' должно быть заполнено.");
            }

            if (_disciplineId.HasValue)
            {
                _disciplineRepository.UpdateDiscipline(CreateDiscipline(_disciplineId.Value));
            }
            else
            {
                _disciplineRepository.CreateDiscipline(CreateDiscipline(0));
            }

            Close();
        }
        catch (Exception ex)
        {
            MessageBox.Show(ex.Message, "Ошибка при сохранении", MessageBoxButtons.OK, MessageBoxIcon.Error);
        }
    }

    private void ButtonCancel_Click(object sender, EventArgs e) => Close();

    private Discipline CreateDiscipline(int id) =>
        Discipline.CreateEntity(id, textBoxNameDiscipline.Text);
}