﻿using ProjectSchedule.Entities;
using ProjectSchedule.Repositories;

namespace ProjectSchedule.Forms;

public partial class FormEducator : Form
{
    private readonly IEducatorRepository _educatorRepository;

    private int? _educatorId;

    public int Id
    {
        set
        {
            try
            {
                var educator = _educatorRepository.ReadEducatorById(value);
                if (educator == null)
                {
                    throw new InvalidDataException(nameof(educator));
                }

                textBoxSurname.Text = educator.Surname;
                textBoxName.Text = educator.Name;
                textBoxPatronymic.Text = educator.Patronymic;
                _educatorId = value;
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Ошибка при получении данных", MessageBoxButtons.OK, MessageBoxIcon.Error);
                return;
            }
        }
    }

    public FormEducator(IEducatorRepository educatorRepository)
    {
        InitializeComponent();
        _educatorRepository = educatorRepository ??
            throw new ArgumentNullException(nameof(educatorRepository));
    }

    private void ButtonSave_Click(object sender, EventArgs e)
    {
        try
        {
            if (string.IsNullOrWhiteSpace(textBoxSurname.Text) || string.IsNullOrWhiteSpace(textBoxName.Text) ||
                string.IsNullOrWhiteSpace(textBoxPatronymic.Text))
            {
                throw new Exception("Имеются незаполненные поля");
            }

            if (_educatorId.HasValue)
            {
                _educatorRepository.UpdateEducator(CreateEducator(_educatorId.Value));
            }
            else
            {
                _educatorRepository.CreateEducator(CreateEducator(0));
            }
            Close();
        }
        catch (Exception ex)
        {
            MessageBox.Show(ex.Message, "Ошибка при сохранении", MessageBoxButtons.OK, MessageBoxIcon.Error);
        }
    }

    private void ButtonCancel_Click(object sender, EventArgs e) => Close();

    private Educator CreateEducator(int id) =>
        Educator.CreateEntity(id, textBoxSurname.Text, textBoxName.Text, textBoxPatronymic.Text);
}