﻿using ProjectSchedule.Entities;
using ProjectSchedule.Repositories;

namespace ProjectSchedule.Forms;

public partial class FormGroupStudents : Form
{
    private readonly IGroupStudentsRepository _groupStudentsRepository;

    private int? _groupStudentsId;

    public int Id
    {
        set
        {
            try
            {
                var groupStudents = _groupStudentsRepository.ReadGroupStudentsById(value);
                if (groupStudents == null)
                {
                    throw new InvalidDataException(nameof(groupStudents));
                }

                textBoxAbbreviationGroup.Text = groupStudents.AbbreviationGroup;
                textBoxGroupNumber.Text = groupStudents.GroupNumber;
                numericUpDownQuantityStudents.Value = groupStudents.QuantityStudents;
                _groupStudentsId = value;
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Ошибка при получении данных", MessageBoxButtons.OK, MessageBoxIcon.Error);
                return;
            }
        }
    }

    public FormGroupStudents(IGroupStudentsRepository groupStudentsRepository)
    {
        InitializeComponent();
        _groupStudentsRepository = groupStudentsRepository ??
            throw new ArgumentNullException(nameof(groupStudentsRepository));
    }

    private void ButtonSave_Click(object sender, EventArgs e)
    {
        try
        {
            if (string.IsNullOrWhiteSpace(textBoxAbbreviationGroup.Text) || string.IsNullOrWhiteSpace(textBoxGroupNumber.Text))
            {
                throw new Exception("Имеются незаполненные поля");
            }

            if (_groupStudentsId.HasValue)
            {
                _groupStudentsRepository.UpdateGroupStudents(CreateGroupOfStudents(_groupStudentsId.Value));
            }
            else
            {
                _groupStudentsRepository.CreateGroupStudents(CreateGroupOfStudents(0));
            }

            Close();
        }
        catch (Exception ex)
        {
            MessageBox.Show(ex.Message, "Ошибка при сохранении", MessageBoxButtons.OK, MessageBoxIcon.Error);
        }
    }

    private void ButtonCancel_Click(object sender, EventArgs e) => Close();

    private GroupStudents CreateGroupOfStudents(int id) =>
        GroupStudents.CreateEntity(id, textBoxAbbreviationGroup.Text, textBoxGroupNumber.Text, Convert.ToInt32(numericUpDownQuantityStudents.Value));
}